@@ -16,8 +16,6 @@
 #ifndef CCTZ_LIBC_H_
 #define CCTZ_LIBC_H_
 
-#ifndef __sun
-
 #include <string>
 
 #include "src/cctz_if.h"
@@ -44,5 +42,3 @@ class TimeZoneLibC : public TimeZoneIf {
 }  // namespace cctz
 
 #endif  // CCTZ_LIBC_H_
-
-#endif
