@@ -13,6 +13,12 @@
 //     See the License for the specific language governing permissions and
 //     limitations under the License.
 
+#if !defined(HAS_STRPTIME)
+# if !defined(_WIN32) && !defined(_WIN64)
+#  define HAS_STRPTIME 1  // assume everyone has strptime() except windows
+# endif
+#endif
+
 #include "src/cctz.h"
 #include "src/cctz_if.h"
 
@@ -22,11 +28,25 @@
 #include <ctime>
 #include <limits>
 #include <vector>
+#if !HAS_STRPTIME
+#include <iomanip>
+#include <sstream>
+#endif
 
 namespace cctz {
 
 namespace {
 
+#if !HAS_STRPTIME
+// Build a strptime() using C++11's std::get_time().
+char* strptime(const char* s, const char* fmt, std::tm* tm) {
+  std::istringstream input(s);
+  input >> std::get_time(tm, fmt);
+  if (input.fail()) return nullptr;
+  return const_cast<char*>(s) + input.tellg();
+}
+#endif
+
 std::tm ToTM(const Breakdown& bd) {
   std::tm tm{};
   tm.tm_sec = bd.second;
@@ -549,6 +569,7 @@ bool Parse(const std::string& format, const std::string& input,
         data = ParseInt(data, 2, 0, 60, &tm.tm_sec);
         continue;
       case 'I':
+      case 'l':
       case 'r':  // probably uses %I
         twelve_hour = true;
         break;
